package com.mrdiro.yourimc

import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.widget.Button
import android.widget.TextView
import androidx.activity.enableEdgeToEdge
import androidx.appcompat.app.AppCompatActivity
import androidx.appcompat.app.AppCompatDelegate
import androidx.cardview.widget.CardView
import androidx.core.content.ContextCompat
import com.google.android.material.slider.Slider
import com.mrdiro.yourimc.screen.ResultScreen

class MainActivity: AppCompatActivity() {
    private lateinit var cardViewMale: CardView
    private lateinit var cardViewFemale: CardView

    private lateinit var imgMaleText: TextView
    private lateinit var imgFemaleText: TextView

    private lateinit var color: Map<String , Int>
    private lateinit var sliderHeight: Slider

    private lateinit var textViewSizeHeight: TextView
    private lateinit var textViewNumberAge: TextView
    private lateinit var textViewNumberWeight: TextView

    private lateinit var buttonAddAge: Button
    private lateinit var buttonSubtractAge: Button
    private lateinit var buttonAddWeight: Button
    private lateinit var buttonSubtractWeight: Button
    private lateinit var buttonCalc: Button

    private var currentAge = 18
    private var currentWeight = 45
    private var currentHeight = 120
    private var genderSelected = ""

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setContentView(R.layout.activity_main)
        enableEdgeToEdge()

        AppCompatDelegate.setDefaultNightMode(AppCompatDelegate.MODE_NIGHT_YES)

        initComponent()
        initListener()
    }

    private fun initComponent() {
        cardViewMale = findViewById(R.id.cardViewMale)
        cardViewFemale = findViewById(R.id.cardViewFemale)

        imgMaleText = findViewById(R.id.imgMaleText)
        imgFemaleText = findViewById(R.id.imgFemaleText)

        sliderHeight = findViewById(R.id.sliderHeight)

        textViewSizeHeight = findViewById(R.id.textViewSizeHeight)
        textViewNumberAge = findViewById(R.id.textViewNumberAge)
        textViewNumberWeight = findViewById(R.id.textViewNumberWeight)

        buttonAddAge = findViewById(R.id.buttonAddAge)
        buttonSubtractAge = findViewById(R.id.buttonSubtractAge)
        buttonAddWeight = findViewById(R.id.buttonAddWeight)
        buttonSubtractWeight = findViewById(R.id.buttonSubtractWeight)
        buttonCalc = findViewById(R.id.buttonCalc)

        color = mapOf(
            "onPrimaryContainer" to  ContextCompat.getColor(this, R.color.md_theme_onPrimaryContainer),
            "primaryContainer" to ContextCompat.getColor(this, R.color.md_theme_primaryContainer),
            "surfContainer" to ContextCompat.getColor(this, R.color.md_theme_surfaceContainer),
            "onSurface" to ContextCompat.getColor(this, R.color.md_theme_onSurface)
        )

        textViewNumberAge.text = currentAge.toString()

        val weight = getString(R.string.main_textView_weightKl, currentWeight)
        textViewNumberWeight.text = weight

        val height = getString(R.string.main_textView_hight, currentHeight)
        textViewSizeHeight.text = height
    }

    private fun initListener() {
        cardViewMale.setOnClickListener { maleSelected() }
        cardViewFemale.setOnClickListener { femaleSelected() }
        sliderHeight.addOnChangeListener { _, value, _ -> setHeight(value) }
        buttonAddAge.setOnClickListener { plusAge() }
        buttonSubtractAge.setOnClickListener { subtractAge() }
        buttonAddWeight.setOnClickListener { plusWeight() }
        buttonSubtractWeight.setOnClickListener { subtractWeight() }
        buttonCalc.setOnClickListener { calc() }
    }

    private fun maleSelected() {
        cardViewMale.setCardBackgroundColor(color["onPrimaryContainer"]!!)
        imgMaleText.setTextColor(color["primaryContainer"]!!)

        cardViewFemale.setCardBackgroundColor(color["surfContainer"]!!)
        imgFemaleText.setTextColor(color["onSurface"]!!)

        genderSelected = "male"
    }

    private fun femaleSelected() {
        cardViewFemale.setCardBackgroundColor(color["onPrimaryContainer"]!!)
        imgFemaleText.setTextColor(color["primaryContainer"]!!)

        cardViewMale.setCardBackgroundColor(color["surfContainer"]!!)
        imgMaleText.setTextColor(color["onSurface"]!!)

        genderSelected = "female"
    }

    private fun setHeight(value: Float) {
        val height = getString(R.string.main_textView_hight, value.toInt())
        currentHeight = value.toInt()
        textViewSizeHeight.text = height
    }

    private fun plusAge() {
        if (currentAge < 110) {
            currentAge++

            textViewNumberAge.text = currentAge.toString()
        }
    }

    private fun subtractAge(){
        if (currentAge > 0) {
            currentAge--

            textViewNumberAge.text = currentAge.toString()
        }
    }

    private fun plusWeight() {
        if (currentWeight < 300) {
            currentWeight++

            val weight = getString(R.string.main_textView_weightKl, currentWeight)
            textViewNumberWeight.text = weight
        }
    }

    private fun subtractWeight() {
        if (currentWeight > 2) {
            currentWeight--

            val weight = getString(R.string.main_textView_weightKl, currentWeight)
            textViewNumberWeight.text = weight
        }
    }

    private fun calc() {
        val heightInMeter = currentHeight.toDouble() / 100
        val imc = currentWeight.toDouble() / (heightInMeter * heightInMeter)
        val intentResultScreen = Intent(this, ResultScreen::class.java)

        intentResultScreen.putExtra("IMC", imc)
        startActivity(intentResultScreen)
    }
}